@@ -12,10 +12,7 @@ from suite_py.lib.handler.captainhook_handler import CaptainHook
 from suite_py.lib.handler.drone_handler import DroneHandler
 from suite_py.lib.handler.git_handler import GitHandler
 from suite_py.lib.handler.github_handler import GithubHandler
-from suite_py.lib.handler.youtrack_handler import (
-    YoutrackHandler,
-    replace_card_names_with_md_links,
-)
+from suite_py.lib.handler.youtrack_handler import YoutrackHandler
 
 
 class Release:
@@ -193,7 +190,9 @@ class Release:
 
     def _create_release(self, new_version, message):
         new_release = self._repo.create_git_release(
-            new_version, new_version, replace_card_names_with_md_links(message)
+            new_version,
+            new_version,
+            self._youtrack.replace_card_names_with_md_links(message),
         )
         if new_release:
             logger.info(f"The release has been created! Link: {new_release.html_url}")
