@@ -7,6 +7,7 @@ from subprocess import CalledProcessError
 import sys
 import requests
 import yaml
+import semver
 
 from halo import Halo
 from suite_py.lib import logger
@@ -142,15 +143,18 @@ class DroneHandler:
                         {
                             "country": country,
                             "version": max(
-                                b["params"]["DRONE_TAG"]
+                                semver.VersionInfo.parse(b["params"]["DRONE_TAG"])
                                 for b in builds
                                 if b["event"] == "promote"
                                 and b["deploy_to"] == f"deploy-{country}-production"
+                                and "params" in b
+                                and "DRONE_TAG" in b["params"]
                             ),
                         }
                         for country in countries
                     ]
-                except Exception:
+                except Exception as e:
+                    logger.warning(f"get_latest_production_deploy: {e}")
                     return []
 
             except Exception as e:
